import { z, ZodType } from "zod";
import { ShareCodeService } from "./share-code.service";
import { TrpcService } from "@server/trpc/trpc.service";
import { Injectable } from "@nestjs/common";
import { Prisma } from "@nice/common";
const ShareCodeWhereInputSchema: ZodType<Prisma.ShareCodeWhereInput> = z.any();
const ShareCodeFindManyArgsSchema: ZodType<Prisma.ShareCodeFindManyArgs> = z.any();
@Injectable()
export class ShareCodeRouter {
    constructor(
        private readonly shareCodeService: ShareCodeService,
        private readonly trpc: TrpcService
    ) { }

    router = this.trpc.router({
        getFileByShareCode: this.trpc.procedure
            .input(z.object({ code: z.string() }))
            .query(async ({ input }) => {
                return this.shareCodeService.getFileByShareCode(input.code);
            }),
        generateShareCodeByFileId: this.trpc.procedure
            .input(z.object({ fileId: z.string(), expiresAt: z.date(), canUseTimes: z.number() }))
            .mutation(async ({ input, ctx }) => {
                return this.shareCodeService.generateShareCodeByFileId(input.fileId, input.expiresAt, input.canUseTimes, ctx.ip);
            }),
        getShareCodesWithResources: this.trpc.procedure
            .input(z.object({ page: z.number(), pageSize: z.number(), where: ShareCodeWhereInputSchema.optional() }))
            .query(async ({ input }) => {
                return this.shareCodeService.getShareCodesWithResources(input);
            }),
        softDeleteShareCodes: this.trpc.procedure
            .input(z.object({ ids: z.array(z.string()) }))
            .mutation(async ({ input }) => {
                return this.shareCodeService.softDeleteShareCodes(input.ids);
            }),
        updateShareCode: this.trpc.procedure
            .input(z.object({
                id: z.string(),
                data: z.object({
                    expiresAt: z.date().optional(),
                    canUseTimes: z.number().optional(),
                })
            }))
            .mutation(async ({ input }) => {
                return this.shareCodeService.updateShareCode(input.id, input.data);
            }),
        getShareCodeResourcesTotalSize: this.trpc.procedure
            .query(async () => {
                return this.shareCodeService.getShareCodeResourcesTotalSize();
            }),
        getShareCodeResourcesSizeByDateRange: this.trpc.procedure
            .input(z.object({ dateType: z.enum(['today', 'yesterday']) }))
            .query(async ({ input }) => {
                return this.shareCodeService.getShareCodeResourcesSizeByDateRange(input.dateType);
            }),
        countDistinctUploadIPs: this.trpc.procedure
            .query(async () => {
                return this.shareCodeService.countDistinctUploadIPs();
            }),
        findShareCodes: this.trpc.procedure
            .input(ShareCodeFindManyArgsSchema)
            .query(async ({ input }) => {
                return this.shareCodeService.findShareCodes(input);
            }),
    });
}