import { useState, useEffect } from "react";
import { Layout, Menu, Button, Space } from "antd";
import { FileOutlined, DashboardOutlined, HomeOutlined, LogoutOutlined } from "@ant-design/icons";
import { NavLink, Outlet, useNavigate, useLocation } from "react-router-dom";
import { useAuth } from "@web/src/providers/auth-provider";

const { Sider, Content } = Layout;

export default function QuickFileManage() {
    const [collapsed, setCollapsed] = useState(false);
    const navigate = useNavigate();
    const location = useLocation();
    const [currentKey, setCurrentKey] = useState("1");
    const { logout } = useAuth();
    
    useEffect(() => {       
        // 根据当前URL路径设置currentKey
        if (location.pathname.includes("/manage/dashboard")) {
            setCurrentKey("1");
        } else if (location.pathname.includes("/manage/share-code")) {
            setCurrentKey("2");
        }
    }, [location.pathname]);
    
    return (
        <Layout style={{ minHeight: "100vh" }}>
            <Sider
                collapsible
                collapsed={collapsed}
                onCollapse={(value) => setCollapsed(value)}
                theme="light"
                style={{
                    borderRight: "1px solid #f0f0f0",
                    display: "flex",
                    flexDirection: "column"
                }}
            >
                <div className="flex items-center justify-center cursor-pointer w-full">
                    <img src="/logo.svg" className="h-10 w-10" />
                    {!collapsed && <span className="text-2xl py-4 mx-4 font-bold text-transparent bg-clip-text bg-gradient-to-r from-blue-500 to-blue-700 drop-shadow-sm">烽火快传</span>}
                </div>
                <Menu
                    theme="light"
                    mode="inline"
                    selectedKeys={[currentKey]}
                    items={[
                        {
                            key: "1",
                            icon: <DashboardOutlined />,
                            label: <NavLink to="/manage/dashboard">数据看板</NavLink>,
                        },
                        {
                            key: "2",
                            icon: <FileOutlined />,
                            label: <NavLink to="/manage/share-code">所有文件</NavLink>,
                        },
                    ]}
                />
                <div className="mt-auto p-2 flex justify-between" style={{marginTop: "auto"}}>
                    <Button 
                        type="link" 
                        icon={<HomeOutlined />} 
                        onClick={() => navigate('/')}
                        style={{flex: 1}}
                    >
                        {!collapsed && "首页"}
                    </Button>
                    <Button 
                        type="link" 
                        icon={<LogoutOutlined />} 
                        onClick={async () => {
                            navigate('/');
                            await logout();
                        }}
                        style={{flex: 1}}
                    >
                        {!collapsed && "登出"}
                    </Button>
                </div>
            </Sider>
            <Content style={{ padding: "24px" }}>
                <Outlet></Outlet>
            </Content>
        </Layout>
    );
}